@@ -41,7 +41,6 @@ namespace Banter
 	public class Person
 	{
 		#region Private Types
-		private string photoFile = String.Empty;
 		private Evolution.Contact edsContact;
 		private string cachePath;
 		private Gdk.Pixbuf avatar;
@@ -179,7 +178,24 @@ namespace Banter
 		public ProviderUser[] ProviderUsers
 		{
 			get{ return providerUsers.ToArray(); }
-		}		
+		}
+		
+
+		/// <summary>
+		/// The Default (by policy) ProviderUser for this Person
+		/// </summary>
+		public ProviderUser ProviderUser
+		{
+			get
+			{ 
+				if(providerUsers.Count > 0) {
+					return providerUsers[0];
+				} else {
+					return null;
+				}
+			}
+		}
+		
 		#endregion
 
 		
